searchData={"items":[{"type":"module","title":"WuunderUtils","doc":"Documentation for `WuunderUtils`.","ref":"WuunderUtils.html"},{"type":"module","title":"WuunderUtils.Maps","doc":"Contains a set of helpers to deal with some complex stuff with Maps and Structs","ref":"WuunderUtils.Maps.html"},{"type":"function","title":"WuunderUtils.Maps.any?/1","doc":"Tests if the map or struct is present","ref":"WuunderUtils.Maps.html#any?/1"},{"type":"function","title":"Examples - WuunderUtils.Maps.any?/1","doc":"iex> WuunderUtils.Maps.any?(nil)\n    false\n\n    iex> WuunderUtils.Maps.any?(%{})\n    false\n\n    iex> WuunderUtils.Maps.any?(%{a: 1})\n    true\n\n    iex> WuunderUtils.Maps.any?(%Person{})\n    true\n\n    iex> WuunderUtils.Maps.any?(%Ecto.Association.NotLoaded{})\n    false","ref":"WuunderUtils.Maps.html#any?/1-examples"},{"type":"function","title":"WuunderUtils.Maps.atomize_keys/2","doc":"Converts keys in maps to atoms. By default, this function will only atomize strings that already exist.\nNote: skips structs.","ref":"WuunderUtils.Maps.html#atomize_keys/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.atomize_keys/2","doc":"iex> WuunderUtils.Maps.atomize_keys(%{\n    ...>   \"first_name\" => \"Peter\",\n    ...>   \"last_name\" => \"Griffin\",\n    ...>   \"skills\" => [%{\"code\" => \"A\", \"title\" => \"Talking\"}, %{\"code\" => \"B\", \"title\" => \"Moving\"}]\n    ...> })\n    %{\n      first_name: \"Peter\",\n      last_name: \"Griffin\",\n      skills: [%{code: \"A\", title: \"Talking\"}, %{code: \"B\", title: \"Moving\"}]\n    }\n\n    iex> WuunderUtils.Maps.atomize_keys(%Person{\n    ...>   first_name: \"Peter\",\n    ...>   last_name: \"Pan\",\n    ...>   date_of_birth: ~D[1980-01-02],\n    ...>   weight: Decimal.new(\"81.5\"),\n    ...>   country: %Country{code: \"UK\"},\n    ...>   time_of_death: ~T[13:37:37],\n    ...>   meta: %{\"skills\" => [%{\"code\" => \"A\", \"title\" => \"Talking\"}, %{\"code\" => \"B\", \"title\" => \"Moving\"}]}\n    ...> })\n    %Person{\n      first_name: \"Peter\",\n      last_name: \"Pan\",\n      date_of_birth: ~D[1980-01-02],\n      weight: Decimal.new(\"81.5\"),\n      country: %Country{code: \"UK\"},\n      time_of_death: ~T[13:37:37],\n      meta: %{skills: [%{code: \"A\", title: \"Talking\"}, %{code: \"B\", title: \"Moving\"}]}\n    }","ref":"WuunderUtils.Maps.html#atomize_keys/2-examples"},{"type":"function","title":"WuunderUtils.Maps.deep_delete/2","doc":"Removes a deeply nested set of keys","ref":"WuunderUtils.Maps.html#deep_delete/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.deep_delete/2","doc":"iex> WuunderUtils.Maps.deep_delete(%{\"data\" => [%{\"name\" => \"Piet\"}, %{\"name\" => \"Henk\"}]}, \"data.0.name\")\n    %{\"data\" => [%{}, %{\"name\" => \"Henk\"}]}\n\n    iex> person = %Person{\n    ...>   country: %Country{code: \"NL\"},\n    ...>   address: %Address{\n    ...>     street: \"Teststreet\",\n    ...>     company: %Company{name: \"Wuunder\"}\n    ...>   },\n    ...>   meta: %{\n    ...>     skills: [\n    ...>       \"programmer\",\n    ...>       \"manager\",\n    ...>       %{type: \"hobby\", name: \"painting\", grades: {\"A+\", \"C\"}}\n    ...>     ]\n    ...>   }\n    ...> }\n    ...>\n    ...> WuunderUtils.Maps.deep_delete(person, [:country, :code])\n    %Person{\n      country: %Country{code: \"\"},\n      address: %Address{\n        street: \"Teststreet\",\n        company: %Company{name: \"Wuunder\"}\n      },\n      meta: %{\n        skills: [\n          \"programmer\",\n          \"manager\",\n          %{type: \"hobby\", name: \"painting\", grades: {\"A+\", \"C\"}}\n        ]\n      }\n    }\n    iex> WuunderUtils.Maps.deep_delete(person, \"meta.skills.1\")\n    %Person{\n      country: %Country{code: \"NL\"},\n      address: %Address{\n        street: \"Teststreet\",\n        company: %Company{name: \"Wuunder\"}\n      },\n      meta: %{\n        skills: [\n          \"programmer\",\n          %{type: \"hobby\", name: \"painting\", grades: {\"A+\", \"C\"}}\n        ]\n      }\n    }","ref":"WuunderUtils.Maps.html#deep_delete/2-examples"},{"type":"function","title":"WuunderUtils.Maps.deep_get/3","doc":"Acts as Kernel.get_in but can also be used on Structs.\nHas a lot of more extra functionalities:\n- You can access lists (nested too)\n- You can use mixed keys, they can be Atoms or Strings\n- You can use a list to access the properties or a string representation","ref":"WuunderUtils.Maps.html#deep_get/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.deep_get/3","doc":"iex> person = %Person{\n    ...>   country: %Country{code: \"NL\"},\n    ...>   address: %Address{\n    ...>     street: \"Teststreet\",\n    ...>     company: %Company{name: \"Wuunder\"}\n    ...>   },\n    ...>   meta: %{\n    ...>     skills: [\n    ...>       \"programmer\",\n    ...>       \"manager\",\n    ...>       %{type: \"hobby\", name: \"painting\", grades: {\"A+\", \"C\"}}\n    ...>     ]\n    ...>   }\n    ...> }\n    ...>\n    ...> WuunderUtils.Maps.deep_get(person, [:country, :code])\n    \"NL\"\n    iex> WuunderUtils.Maps.deep_get(person, \"country.code\")\n    \"NL\"\n    iex> WuunderUtils.Maps.deep_get(person, [:address, :company])\n    %Company{name: \"Wuunder\"}\n    iex> WuunderUtils.Maps.deep_get(person, [:address, :company, :name])\n    \"Wuunder\"\n    iex> WuunderUtils.Maps.deep_get(person, [:meta, :skills])\n    [\"programmer\", \"manager\", %{name: \"painting\", type: \"hobby\", grades: {\"A+\", \"C\"}}]\n    iex> WuunderUtils.Maps.deep_get(person, [:meta, :skills, 1])\n    \"manager\"\n    iex> WuunderUtils.Maps.deep_get(person, \"meta.skills.1\")\n    \"manager\"\n    iex> WuunderUtils.Maps.deep_get(person, [:meta, :skills, 2, :type])\n    \"hobby\"\n    iex> WuunderUtils.Maps.deep_get(person, \"meta.skills.2.type\")\n    \"hobby\"\n    iex> WuunderUtils.Maps.deep_get(person, \"meta.skills.2.non_existent\")\n    nil\n    iex> WuunderUtils.Maps.deep_get(person, \"meta.skills.2.non_existent\", \"default\")\n    \"default\"\n    iex> WuunderUtils.Maps.deep_get(person, \"meta.skills.2.grades.0\")\n    \"A+\"\n    iex> WuunderUtils.Maps.deep_get(person, \"meta.skills.2.grades.2\", \"none\")\n    \"none\"\n\n    iex> keyword_list = [\n    ...>   name: \"Henk\",\n    ...>   last_name: \"Jansen\",\n    ...>   addresses: [\n    ...>     %{\"street\" => \"Laan\", \"number\" => 1},\n    ...>     %{\"street\" => \"Straat\", \"number\" => 1337}\n    ...>   ]\n    ...> ]\n    ...>\n    iex> WuunderUtils.Maps.deep_get(keyword_list, \"name\")\n    \"Henk\"\n    iex> WuunderUtils.Maps.deep_get(keyword_list, \"addresses\")\n    [%{\"number\" => 1, \"street\" => \"Laan\"}, %{\"number\" => 1337, \"street\" => \"Straat\"}]\n    iex> WuunderUtils.Maps.deep_get(keyword_list, \"addresses.0\")\n    %{\"number\" => 1, \"street\" => \"Laan\"}\n    iex> WuunderUtils.Maps.deep_get(keyword_list, \"addresses.1.street\")\n    \"Straat\"\n    iex> WuunderUtils.Maps.deep_get(keyword_list, \"addresses.1.other_field\", \"none\")\n    \"none\"\n    iex> WuunderUtils.Maps.deep_get(keyword_list, \"addresses.2.other_field\", \"none\")\n    nil","ref":"WuunderUtils.Maps.html#deep_get/3-examples"},{"type":"function","title":"WuunderUtils.Maps.deep_get_values/2","doc":"Creates a map from a given set of fields. The output will always be a string.","ref":"WuunderUtils.Maps.html#deep_get_values/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.deep_get_values/2","doc":"iex> person = %Person{\n    ...>   country: %Country{code: \"NL\"},\n    ...>   address: %Address{\n    ...>     street: \"Teststreet\",\n    ...>     company: %Company{name: \"Wuunder\"}\n    ...>   },\n    ...>   meta: %{\n    ...>     skills: [\n    ...>       \"programmer\",\n    ...>       \"manager\",\n    ...>       %{type: \"hobby\", name: \"painting\"}\n    ...>     ]\n    ...>   }\n    ...> }\n    ...>\n    ...> WuunderUtils.Maps.deep_get_values(\n    ...>   person,\n    ...>   [\n    ...>     [:country, :code],\n    ...>     [:address, :street],\n    ...>     [:meta, :skills, 2, :type]\n    ...>   ]\n    ...> )\n    %{\n      \"address\" => %{\"street\" => \"Teststreet\"},\n      \"country\" => %{\"code\" => \"NL\"},\n      \"meta\" => %{\n        \"skills\" => [\n          %{\"type\" => \"hobby\"}\n        ]\n      }\n    }","ref":"WuunderUtils.Maps.html#deep_get_values/2-examples"},{"type":"function","title":"WuunderUtils.Maps.deep_put/3","doc":"Acts as Kernel.put-in but can also be used on Structs.\nHas a lot of more extra functionalities:\n- You can access lists (nested too)\n- You can use mixed keys, they can be Atoms or Strings\n- You can use a list to access the properties or a string representation","ref":"WuunderUtils.Maps.html#deep_put/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.deep_put/3","doc":"iex> person = %Person{\n    ...>   country: %Country{code: \"NL\"},\n    ...>   address: %Address{\n    ...>     street: \"Teststreet\",\n    ...>     company: %Company{name: \"Wuunder\"}\n    ...>   },\n    ...>   meta: %{\n    ...>     skills: [\n    ...>       \"programmer\",\n    ...>       \"manager\",\n    ...>       %{type: \"hobby\", name: \"painting\"}\n    ...>     ]\n    ...>   }\n    ...> }\n    iex> WuunderUtils.Maps.deep_put(person, [:first_name], \"Piet\")\n    %Person{person | first_name: \"Piet\"}\n    iex> WuunderUtils.Maps.deep_put(person, [:country, :code], \"US\")\n    %Person{person | country: %Country{code: \"US\"}}\n    iex> WuunderUtils.Maps.deep_put(person, [:meta, :skills, 1], \"vaultdweller\")\n    %Person{person | meta: %{skills: [\"programmer\", \"vaultdweller\", %{name: \"painting\", type: \"hobby\"}]}}\n    iex> WuunderUtils.Maps.deep_put(person, [:meta, :skills, 2, :name], \"walking\")\n    %Person{person | meta: %{skills: [\"programmer\", \"manager\", %{name: \"walking\", type: \"hobby\"}]}}\n    iex> WuunderUtils.Maps.deep_put(person, \"meta.skills.2.name\", \"walking\")\n    %Person{person | meta: %{skills: [\"programmer\", \"manager\", %{name: \"walking\", type: \"hobby\"}]}}","ref":"WuunderUtils.Maps.html#deep_put/3-examples"},{"type":"function","title":"WuunderUtils.Maps.delete/2","doc":"Removes a key from a map. Doesn't matter if the key is an atom or string","ref":"WuunderUtils.Maps.html#delete/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.delete/2","doc":"iex> WuunderUtils.Maps.delete(%{length: 255, weight: 100}, :length)\n    %{weight: 100}\n\n    iex> WuunderUtils.Maps.delete(%{length: 255, weight: 100}, \"length\")\n    %{weight: 100}\n\n    iex> WuunderUtils.Maps.delete(%{\"value\" => 50, \"currency\" => \"EUR\"}, \"currency\")\n    %{\"value\" => 50}\n\n    iex> WuunderUtils.Maps.delete(%{\"value\" => 50, \"currency\" => \"EUR\"}, :currency)\n    %{\"value\" => 50}\n\n    iex> WuunderUtils.Maps.delete([\"a\", \"b\", \"c\"], 1)\n    [\"a\", \"c\"]\n\n    iex> WuunderUtils.Maps.delete({\"a\", \"b\", \"c\"}, 1)\n    {\"a\", \"c\"}\n\n    iex> country = %Country{code: \"NL\"}\n    ...>\n    ...> WuunderUtils.Maps.delete(country, :code)\n    %Country{code: \"\"}\n\n    iex> country = %Country{code: \"NL\"}\n    ...>\n    ...> WuunderUtils.Maps.delete(country, \"code\")\n    %Country{code: \"\"}\n\n    iex> country = %Country{code: \"NL\"}\n    ...>\n    ...> WuunderUtils.Maps.delete(country, \"does_not_exist\")\n    %Country{code: \"NL\"}","ref":"WuunderUtils.Maps.html#delete/2-examples"},{"type":"function","title":"WuunderUtils.Maps.delete_all/2","doc":"Deletes a list of keys from a map (and all nested maps, lists)\nUsefull when you want to scrub out IDs for instance.","ref":"WuunderUtils.Maps.html#delete_all/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.delete_all/2","doc":"iex> WuunderUtils.Maps.delete_all(\n    ...>   %{\n    ...>      shipment: %{\n    ...>        id: \"shipment-id\",\n    ...>        wuunder_id: \"WUUNDERID\"\n    ...>      },\n    ...>      order_lines: [\n    ...>        %{id: \"123\", sku: \"SKU01\"},\n    ...>        %{id: \"456\", sku: \"SKU02\"},\n    ...>        %{id: \"789\", sku: \"SKU03\"}\n    ...>      ],\n    ...>      meta: %{\n    ...>        configuration_id: \"nothing\"\n    ...>      }\n    ...>   },\n    ...>   [:id, :configuration_id]\n    ...> )\n    %{\n      meta: %{},\n      order_lines: [%{sku: \"SKU01\"}, %{sku: \"SKU02\"}, %{sku: \"SKU03\"}],\n      shipment: %{wuunder_id: \"WUUNDERID\"}\n    }\n\n    iex> WuunderUtils.Maps.delete_all([\n    ...>   %{id: \"123\", name: \"test1\"},\n    ...>   %{id: \"456\", name: \"test2\"},\n    ...>   %{id: \"789\", name: \"test3\"}\n    ...> ], [:id])\n    [%{name: \"test1\"}, %{name: \"test2\"}, %{name: \"test3\"}]","ref":"WuunderUtils.Maps.html#delete_all/2-examples"},{"type":"function","title":"WuunderUtils.Maps.delete_empty/1","doc":"Trims an incoming map/list/tuple. Removes all keys that have a `nil` value. Structs with an empty value\nwill reset to the default value. Items in lists and tuples that contain nil values will be deleted.","ref":"WuunderUtils.Maps.html#delete_empty/1"},{"type":"function","title":"Examples - WuunderUtils.Maps.delete_empty/1","doc":"iex> WuunderUtils.Maps.delete_empty(%{name: nil, last_name: \"Jansen\"})\n      %{last_name: \"Jansen\"}\n\n      iex> WuunderUtils.Maps.delete_empty(%{name: nil, last_name: nil})\n      nil\n\n      iex> WuunderUtils.Maps.delete_empty({1, 2, nil, 3, 4})\n      {1, 2, 3, 4}\n\n      iex> WuunderUtils.Maps.delete_empty([1, 2, nil, 3, 4])\n      [1, 2, 3, 4]\n\n      iex> WuunderUtils.Maps.delete_empty(%{items: [%{a: nil, b: nil}, %{a: 1, b: 2}]})\n      %{items: [%{a: 1, b: 2}]}\n\n      iex> WuunderUtils.Maps.delete_empty(%{items: [%{a: [1, nil, %{x: 1337, y: {1, nil, 2, {nil, nil}}}], b: nil}, %{a: 1, b: 2}]})\n      %{items: [%{a: [1, %{y: {1, 2}, x: 1337}]}, %{a: 1, b: 2}]}","ref":"WuunderUtils.Maps.html#delete_empty/1-examples"},{"type":"function","title":"WuunderUtils.Maps.flatten/1","doc":"Flattens a map. This results in a map that just contains one level","ref":"WuunderUtils.Maps.html#flatten/1"},{"type":"function","title":"Options - WuunderUtils.Maps.flatten/1","doc":"- key_separator (default .)\n- underscore_key (default true)\n- list_index_start (default 1)","ref":"WuunderUtils.Maps.html#flatten/1-options"},{"type":"function","title":"Example - WuunderUtils.Maps.flatten/1","doc":"iex> WuunderUtils.Maps.flatten(%{\n    ...>   test: \"123\",\n    ...>   order_lines: [\n    ...>     %{sku: \"123\", description: \"test\"},\n    ...>     %{sku: \"456\", description: \"test 2\"}\n    ...>   ],\n    ...>   meta: %{\n    ...>     data: \"test\"\n    ...>   }\n    ...> })\n    %{\n      \"test\" => \"123\",\n      \"order_lines.1.sku\" => \"123\",\n      \"order_lines.1.description\" => \"test\",\n      \"order_lines.2.sku\" => \"456\",\n      \"order_lines.2.description\" => \"test 2\",\n      \"meta.data\" => \"test\"\n    }\n\n    iex> WuunderUtils.Maps.flatten({1, 2, 3})\n    %{\n      \"1\" => 1,\n      \"2\" => 2,\n      \"3\" => 3,\n    }\n\n    iex> WuunderUtils.Maps.flatten([\n    ...>     %{sku: \"123\", description: \"test\"},\n    ...>     %{sku: \"456\", description: \"test 2\"}\n    ...> ])\n    %{\n      \"1.sku\" => \"123\",\n      \"1.description\" => \"test\",\n      \"2.sku\" => \"456\",\n      \"2.description\" => \"test 2\"\n    }\n\n    iex> WuunderUtils.Maps.flatten(\n    ...>   %{\n    ...>     test: \"123\",\n    ...>     order_lines: [\n    ...>       %{sku: \"123\", description: \"test\"},\n    ...>       %{sku: \"456\", description: \"test 2\"}\n    ...>     ],\n    ...>     meta: %{\n    ...>       data: \"test\"\n    ...>     },\n    ...>     tuple: {1, 2, 3}\n    ...>   },\n    ...>   key_separator: \"_\",\n    ...>   list_index_start: 0\n    ...> )\n    %{\n      \"test\" => \"123\",\n      \"order_lines_0_sku\" => \"123\",\n      \"order_lines_0_description\" => \"test\",\n      \"order_lines_1_sku\" => \"456\",\n      \"order_lines_1_description\" => \"test 2\",\n      \"tuple_0\" => 1,\n      \"tuple_1\" => 2,\n      \"tuple_2\" => 3,\n      \"meta_data\" => \"test\"\n    }","ref":"WuunderUtils.Maps.html#flatten/1-example"},{"type":"function","title":"WuunderUtils.Maps.flatten/2","doc":"","ref":"WuunderUtils.Maps.html#flatten/2"},{"type":"function","title":"WuunderUtils.Maps.flatten/4","doc":"","ref":"WuunderUtils.Maps.html#flatten/4"},{"type":"function","title":"WuunderUtils.Maps.from_struct/1","doc":"Creates a clean map from a given struct.\nThis function deep structs, maps, lists etc. to a map\nand uses a set of default transformers as defined in `default_struct_fransform/0`.\n\nThere is also an option to omit the `transform` option to add an extra set of transformers.\n\nTook some inspiration from this great lib: https://github.com/prodis/miss-elixir/blob/0.1.5/lib/miss/map.ex\n\nNote: It's also able to convert Ecto models to flat maps. It uses the defined Ecto fields for that.","ref":"WuunderUtils.Maps.html#from_struct/1"},{"type":"function","title":"Examples - WuunderUtils.Maps.from_struct/1","doc":"iex> WuunderUtils.Maps.from_struct(%Person{\n    ...>   first_name: \"Peter\",\n    ...>   last_name: \"Pan\",\n    ...>   date_of_birth: ~D[1980-01-02],\n    ...>   weight: Decimal.new(\"81.5\"),\n    ...>   country: %{code: \"UK\"},\n    ...>   time_of_death: ~T[13:37:37]\n    ...> })\n    %{\n      address: nil,\n      date_of_birth: \"1980-01-02\",\n      first_name: \"Peter\",\n      last_name: \"Pan\",\n      time_of_death: \"13:37:37\",\n      weight: \"81.5\",\n      country: %{code: \"UK\"},\n      meta: %{}\n    }\n\n    iex> WuunderUtils.Maps.from_struct(\n    ...>   %Person{\n    ...>     first_name: \"Peter\",\n    ...>     last_name: \"Pan\",\n    ...>     date_of_birth: ~D[1980-01-02],\n    ...>     weight: Decimal.new(\"81.5\"),\n    ...>     country: %Country{code: \"UK\"},\n    ...>     time_of_death: ~T[13:37:37]\n    ...>   },\n    ...>   transform: [{Country, fn x -> \"COUNTRY:\" <> x.code end}]\n    ...> )\n    %{\n      address: nil,\n      date_of_birth: \"1980-01-02\",\n      first_name: \"Peter\",\n      last_name: \"Pan\",\n      time_of_death: \"13:37:37\",\n      weight: \"81.5\",\n      country: \"COUNTRY:UK\",\n      meta: %{}\n    }\n\n    iex> WuunderUtils.Maps.from_struct(\n    ...>   %Person{\n    ...>     address: %Address{\n    ...>       street: \"Straat\",\n    ...>       number: 13,\n    ...>       zipcode: \"1122AB\"\n    ...>     },\n    ...>     first_name: \"Peter\",\n    ...>     last_name: \"Pan\",\n    ...>     date_of_birth: ~D[1980-01-02],\n    ...>     weight: Decimal.new(\"81.5\"),\n    ...>     country: %{code: \"UK\"},\n    ...>     time_of_death: ~T[13:37:37]\n    ...>   }\n    ...> )\n    %{\n      address: %{company: nil, number: 13, street: \"Straat\", zipcode: \"1122AB\"},\n      date_of_birth: \"1980-01-02\",\n      first_name: \"Peter\",\n      last_name: \"Pan\",\n      time_of_death: \"13:37:37\",\n      weight: \"81.5\",\n      country: %{code: \"UK\"},\n      meta: %{}\n    }","ref":"WuunderUtils.Maps.html#from_struct/1-examples"},{"type":"function","title":"WuunderUtils.Maps.from_struct/2","doc":"","ref":"WuunderUtils.Maps.html#from_struct/2"},{"type":"function","title":"WuunderUtils.Maps.get/3","doc":"Retrieves a key from a map regardless of the key type (atom/string)\nNote: This function does not generate new atoms on the fly.","ref":"WuunderUtils.Maps.html#get/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.get/3","doc":"iex> WuunderUtils.Maps.get(%{value: 20}, :value)\n    20\n\n    iex> WuunderUtils.Maps.get(%{\"value\" => 20}, :value)\n    20\n\n    iex> WuunderUtils.Maps.get(%{value: 20}, \"value\")\n    20\n\n    iex> WuunderUtils.Maps.get(%{value: 20}, \"non-existent\")\n    nil\n\n    iex> WuunderUtils.Maps.get(%{value: 20}, :weight)\n    nil\n\n    iex> WuunderUtils.Maps.get(%{value: 20}, :weight, 350)\n    350\n\n    iex> WuunderUtils.Maps.get(%{value: 20}, \"currency\", \"EUR\")\n    \"EUR\"\n\n    iex> WuunderUtils.Maps.get([name: \"Henk\", name: \"Kees\", last_name: \"Jansen\"], \"name\")\n    \"Henk\"\n\n    iex> WuunderUtils.Maps.get([\"a\", \"b\", \"c\"], 1)\n    \"b\"\n\n\n    iex> WuunderUtils.Maps.get([\"a\", \"b\", \"c\"], 3, \"d\")\n    \"d\"\n\n    iex> WuunderUtils.Maps.get({\"a\", \"b\", \"c\"}, 1)\n    \"b\"\n\n    iex> WuunderUtils.Maps.get({\"a\", \"b\", \"c\"}, 3, \"d\")\n    \"d\"","ref":"WuunderUtils.Maps.html#get/3-examples"},{"type":"macro","title":"WuunderUtils.Maps.is_valid_map_atom_key/1","doc":"","ref":"WuunderUtils.Maps.html#is_valid_map_atom_key/1"},{"type":"macro","title":"WuunderUtils.Maps.is_valid_map_binary_key/1","doc":"","ref":"WuunderUtils.Maps.html#is_valid_map_binary_key/1"},{"type":"macro","title":"WuunderUtils.Maps.is_valid_map_key/1","doc":"","ref":"WuunderUtils.Maps.html#is_valid_map_key/1"},{"type":"function","title":"WuunderUtils.Maps.map/2","doc":"Maps a given function over entire structure (map/list/struct/tuple)","ref":"WuunderUtils.Maps.html#map/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.map/2","doc":"iex> WuunderUtils.Maps.map(%{name: \" test \", data: [\"some item\", \"other item   \", %{x: \"  value\"}]}, &WuunderUtils.Presence.trim/1)\n      %{data: [\"some item\", \"other item\", %{x: \"value\"}], name: \"test\"}","ref":"WuunderUtils.Maps.html#map/2-examples"},{"type":"function","title":"WuunderUtils.Maps.new/1","doc":"Generates an empty map and list from a given set of keys","ref":"WuunderUtils.Maps.html#new/1"},{"type":"function","title":"Examples - WuunderUtils.Maps.new/1","doc":"iex> WuunderUtils.Maps.new([:person, :name, :meta, 0, :hobby, :type])\n    %{\"person\" => %{\"name\" => %{\"meta\" => [%{\"hobby\" => %{\"type\" => %{}}}]}}}\n\n    iex> WuunderUtils.Maps.new([:person, :name, :meta, 0, :hobbies, 0, :type])\n    %{\"person\" => %{\"name\" => %{\"meta\" => [%{\"hobbies\" => [%{\"type\" => %{}}]}]}}}","ref":"WuunderUtils.Maps.html#new/1-examples"},{"type":"function","title":"WuunderUtils.Maps.new/2","doc":"","ref":"WuunderUtils.Maps.html#new/2"},{"type":"function","title":"WuunderUtils.Maps.only_atom_keys?/1","doc":"Tests if the given map only consists of atom keys","ref":"WuunderUtils.Maps.html#only_atom_keys?/1"},{"type":"function","title":"Examples - WuunderUtils.Maps.only_atom_keys?/1","doc":"iex> WuunderUtils.Maps.only_atom_keys?(%{a: 1, b: 2})\n    true\n\n    iex> WuunderUtils.Maps.only_atom_keys?(%{:a => 1, \"b\" => 2})\n    false\n\n    iex> WuunderUtils.Maps.only_atom_keys?(%{\"a\" => 1, \"b\" => 2})\n    false","ref":"WuunderUtils.Maps.html#only_atom_keys?/1-examples"},{"type":"function","title":"WuunderUtils.Maps.put/3","doc":"Acts as an IndifferentMap. Put a key/value regardless of the key type. If the map\ncontains keys as atoms, the value will be stored as atom: value. If the map contains\nstrings as keys it will store the value as binary: value","ref":"WuunderUtils.Maps.html#put/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.put/3","doc":"iex> WuunderUtils.Maps.put(%{value: 20}, :weight, 350)\n    %{value: 20, weight: 350}\n\n    iex> WuunderUtils.Maps.put([\"a\", \"b\", \"c\"], 1, \"d\")\n    [\"a\", \"d\", \"c\"]\n\n    iex> WuunderUtils.Maps.put([\"a\", \"b\", \"c\"], 4, \"d\")\n    [\"a\", \"b\", \"c\"]\n\n    iex> WuunderUtils.Maps.put(%{value: 20, weight: 200}, \"weight\", 350)\n    %{value: 20, weight: 350}\n\n    iex> WuunderUtils.Maps.put(%{value: 20}, \"weight\", 350)\n    %{:value => 20, \"weight\" => 350}\n\n    iex> WuunderUtils.Maps.put(%{\"weight\" => 350}, :value, 25)\n    %{\"weight\" => 350, \"value\" => 25}\n\n    iex> WuunderUtils.Maps.put(%{\"weight\" => 350}, \"value\", 25)\n    %{\"weight\" => 350, \"value\" => 25}","ref":"WuunderUtils.Maps.html#put/3-examples"},{"type":"function","title":"WuunderUtils.Maps.put_if_not_nil/3","doc":"Only puts value in map when value is actually nil (not the same as empty)","ref":"WuunderUtils.Maps.html#put_if_not_nil/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.put_if_not_nil/3","doc":"iex> WuunderUtils.Maps.put_if_not_nil(%{street: \"Straat\"}, :street, \"Laan\")\n    %{street: \"Laan\"}\n\n    iex> WuunderUtils.Maps.put_if_not_nil(%{street: \"Straat\"}, :street, nil)\n    %{street: \"Straat\"}\n\n    iex> WuunderUtils.Maps.put_if_not_nil(%{street: \"Straat\"}, :street, \"     \")\n    %{street: \"     \"}","ref":"WuunderUtils.Maps.html#put_if_not_nil/3-examples"},{"type":"function","title":"WuunderUtils.Maps.put_if_present/3","doc":"Only puts value in map when the value is considered empty","ref":"WuunderUtils.Maps.html#put_if_present/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.put_if_present/3","doc":"iex> WuunderUtils.Maps.put_if_present(%{street: \"Straat\"}, :street, \"Laan\")\n    %{street: \"Laan\"}\n\n    iex> WuunderUtils.Maps.put_if_present(%{street: \"Straat\"}, :street, nil)\n    %{street: \"Straat\"}\n\n    iex> WuunderUtils.Maps.put_if_present(%{street: \"Straat\"}, :street, \"     \")\n    %{street: \"Straat\"}","ref":"WuunderUtils.Maps.html#put_if_present/3-examples"},{"type":"function","title":"WuunderUtils.Maps.put_when/4","doc":"Conditionally puts a value to a given map. Depending on the condition or the value, the\nkey+value will be set to the map","ref":"WuunderUtils.Maps.html#put_when/4"},{"type":"function","title":"Examples - WuunderUtils.Maps.put_when/4","doc":"iex> WuunderUtils.Maps.put_when(%{street: \"Straat\"}, 1 == 1, :number, 13)\n    %{number: 13, street: \"Straat\"}\n\n    iex> WuunderUtils.Maps.put_when(%{street: \"Straat\"}, fn -> \"value\" == \"value\" end, :number, 13)\n    %{number: 13, street: \"Straat\"}\n\n    iex> WuunderUtils.Maps.put_when(%{street: \"Straat\"}, 10 > 20, :number, 13)\n    %{street: \"Straat\"}","ref":"WuunderUtils.Maps.html#put_when/4-examples"},{"type":"function","title":"WuunderUtils.Maps.rename_key/3","doc":"Maps a given field from given (if not in map)","ref":"WuunderUtils.Maps.html#rename_key/3"},{"type":"function","title":"Examples - WuunderUtils.Maps.rename_key/3","doc":"iex> WuunderUtils.Maps.rename_key(%{country: \"NL\"}, :country, :country_code)\n    %{country_code: \"NL\"}\n\n    iex> WuunderUtils.Maps.rename_key(%{\"country\" => \"NL\"}, :country, :country_code)\n    %{\"country_code\" => \"NL\"}\n\n    iex> WuunderUtils.Maps.rename_key(%{street_name: \"Straatnaam\"}, :street, :street_address)\n    %{street_name: \"Straatnaam\"}","ref":"WuunderUtils.Maps.html#rename_key/3-examples"},{"type":"function","title":"WuunderUtils.Maps.rename_keys/2","doc":"Mass maps a given input with aliasses","ref":"WuunderUtils.Maps.html#rename_keys/2"},{"type":"function","title":"Examples - WuunderUtils.Maps.rename_keys/2","doc":"iex> WuunderUtils.Maps.rename_keys(%{country: \"NL\", street: \"Straat\", number: 666}, %{country: :country_code, street: :street_name, number: :house_number})\n    %{country_code: \"NL\", house_number: 666, street_name: \"Straat\"}","ref":"WuunderUtils.Maps.html#rename_keys/2-examples"},{"type":"function","title":"WuunderUtils.Maps.stringify_keys/1","doc":"Converts keys in maps to strings. Note: skips structs. So you need to convert these to maps first.","ref":"WuunderUtils.Maps.html#stringify_keys/1"},{"type":"function","title":"Examples - WuunderUtils.Maps.stringify_keys/1","doc":"iex> WuunderUtils.Maps.stringify_keys(%{\n    ...>   first_name: \"Peter\",\n    ...>   last_name: \"Griffin\",\n    ...>   skills: [%{code: \"A\", title: \"Talking\"}, %{code: \"B\", title: \"Moving\"}]\n    ...> })\n    %{\n      \"first_name\" => \"Peter\",\n      \"last_name\" => \"Griffin\",\n      \"skills\" => [%{\"code\" => \"A\", \"title\" => \"Talking\"}, %{\"code\" => \"B\", \"title\" => \"Moving\"}]\n    }\n\n    iex> WuunderUtils.Maps.stringify_keys(%Person{\n    ...>   first_name: \"Peter\",\n    ...>   last_name: \"Pan\",\n    ...>   date_of_birth: ~D[1980-01-02],\n    ...>   weight: Decimal.new(\"81.5\"),\n    ...>   country: %Country{code: \"UK\"},\n    ...>   time_of_death: ~T[13:37:37],\n    ...>   meta: %{skills: [%{code: \"A\", title: \"Talking\"}, %{code: \"B\", title: \"Moving\"}]}\n    ...> })\n    %Person{\n      first_name: \"Peter\",\n      last_name: \"Pan\",\n      date_of_birth: ~D[1980-01-02],\n      weight: Decimal.new(\"81.5\"),\n      country: %Country{code: \"UK\"},\n      time_of_death: ~T[13:37:37],\n      meta: %{\"skills\" => [%{\"code\" => \"A\", \"title\" => \"Talking\"}, %{\"code\" => \"B\", \"title\" => \"Moving\"}]}\n    }","ref":"WuunderUtils.Maps.html#stringify_keys/1-examples"},{"type":"type","title":"WuunderUtils.Maps.map_key/0","doc":"","ref":"WuunderUtils.Maps.html#t:map_key/0"},{"type":"module","title":"WuunderUtils.Numbers","doc":"Helper functions for floats, ints and Decimal's","ref":"WuunderUtils.Numbers.html"},{"type":"function","title":"WuunderUtils.Numbers.add_decimal/2","doc":"Adds two Decimal's together. Defaults back to 0.","ref":"WuunderUtils.Numbers.html#add_decimal/2"},{"type":"function","title":"Examples - WuunderUtils.Numbers.add_decimal/2","doc":"iex> WuunderUtils.Numbers.add_decimal(nil, nil)\n    Decimal.new(\"0\")\n\n    iex> WuunderUtils.Numbers.add_decimal(nil, Decimal.new(\"15.5\"))\n    Decimal.new(\"15.5\")\n\n    iex> WuunderUtils.Numbers.add_decimal(Decimal.new(\"6.5\"), Decimal.new(\"15.5\"))\n    Decimal.new(\"22.0\")\n\n    iex> WuunderUtils.Numbers.add_decimal(Decimal.new(\"15.5\"), nil)\n    Decimal.new(\"15.5\")","ref":"WuunderUtils.Numbers.html#add_decimal/2-examples"},{"type":"function","title":"WuunderUtils.Numbers.any?/1","doc":"Tests if number is \"present\". Meaning: the number must not be 0, 0.0. Positive or negative is ok.\nAlso a tiny fraction just above 0 is allowed.","ref":"WuunderUtils.Numbers.html#any?/1"},{"type":"function","title":"Examples - WuunderUtils.Numbers.any?/1","doc":"iex> WuunderUtils.Numbers.any?(-1)\n    true\n\n    iex> WuunderUtils.Numbers.any?(1)\n    true\n\n    iex> WuunderUtils.Numbers.any?(Decimal.new(\"1\"))\n    true\n\n    iex> WuunderUtils.Numbers.any?(0.000001)\n    true\n\n    iex> WuunderUtils.Numbers.any?(0.0)\n    false\n\n    iex> WuunderUtils.Numbers.any?(0)\n    false\n\n    iex> WuunderUtils.Numbers.any?(Decimal.new(\"0\"))\n    false\n\n    iex> WuunderUtils.Numbers.any?(Decimal.new(\"0.0\"))\n    false","ref":"WuunderUtils.Numbers.html#any?/1-examples"},{"type":"function","title":"WuunderUtils.Numbers.as_string/1","doc":"Tries to convert a number to a string. When the given value is already a binary, it tries to parse it and output it accordingly.","ref":"WuunderUtils.Numbers.html#as_string/1"},{"type":"function","title":"Examples - WuunderUtils.Numbers.as_string/1","doc":"iex> WuunderUtils.Numbers.as_string(13.37)\n    \"13.37\"\n\n    iex> WuunderUtils.Numbers.as_string(Decimal.new(\"13.37\"))\n    \"13.37\"\n\n    iex> WuunderUtils.Numbers.as_string(1337)\n    \"1337\"\n\n    iex> WuunderUtils.Numbers.as_string(\"1337\")\n    \"1337.0\"\n\n    iex> WuunderUtils.Numbers.as_string(\"1abc300\")\n    \"1.0\"","ref":"WuunderUtils.Numbers.html#as_string/1-examples"},{"type":"function","title":"WuunderUtils.Numbers.decimal_zero?/1","doc":"Checks if given String.t() or float() ends with a zero decimal.\n\nA String.t() is parsed and returns `false` if the parsing failed.","ref":"WuunderUtils.Numbers.html#decimal_zero?/1"},{"type":"function","title":"Examples - WuunderUtils.Numbers.decimal_zero?/1","doc":"iex> WuunderUtils.Numbers.decimal_zero?(4.5)\n    false\n\n    iex> WuunderUtils.Numbers.decimal_zero?(1.0003)\n    false\n\n    iex> WuunderUtils.Numbers.decimal_zero?(\"4.0000\")\n    true\n\n    iex> WuunderUtils.Numbers.decimal_zero?(6)\n    true\n\n    iex> WuunderUtils.Numbers.decimal_zero?(\"5.0\")\n    true\n\n    iex> WuunderUtils.Numbers.decimal_zero?(nil)\n    false","ref":"WuunderUtils.Numbers.html#decimal_zero?/1-examples"},{"type":"function","title":"WuunderUtils.Numbers.empty?/1","doc":"Reverse of any?","ref":"WuunderUtils.Numbers.html#empty?/1"},{"type":"function","title":"WuunderUtils.Numbers.parse_float/1","doc":"Parses a String.t() to a float(). Just passes float()\nbut does convert integer() to a float().\n\nWhen parsing fails, this function returns a `nil`.","ref":"WuunderUtils.Numbers.html#parse_float/1"},{"type":"function","title":"Examples - WuunderUtils.Numbers.parse_float/1","doc":"iex> WuunderUtils.Numbers.parse_float(\"10005\")\n    10005.0\n\n    iex> WuunderUtils.Numbers.parse_float(10005)\n    10005\n\n    iex> WuunderUtils.Numbers.parse_float(10.5)\n    10.5\n\n    iex> WuunderUtils.Numbers.parse_float(\"10.50\")\n    10.5\n\n    iex> WuunderUtils.Numbers.parse_float(\"TEST10.50\")\n    nil\n\n    iex> WuunderUtils.Numbers.parse_float(\"10TEST2\")\n    10.0","ref":"WuunderUtils.Numbers.html#parse_float/1-examples"},{"type":"function","title":"WuunderUtils.Numbers.parse_int/1","doc":"Parses a string to an int. Returns `nil` if that didn't work out.","ref":"WuunderUtils.Numbers.html#parse_int/1"},{"type":"function","title":"Examples - WuunderUtils.Numbers.parse_int/1","doc":"iex> WuunderUtils.Numbers.parse_int(\"10005\")\n    10005\n\n    iex> WuunderUtils.Numbers.parse_int(10005)\n    10005\n\n    iex> WuunderUtils.Numbers.parse_int(10.5)\n    10.5\n\n    iex> WuunderUtils.Numbers.parse_int(\"10.50\")\n    10\n\n    iex> WuunderUtils.Numbers.parse_int(\"TEST10.50\")\n    nil\n\n    iex> WuunderUtils.Numbers.parse_int(\"10TEST2\")\n    10","ref":"WuunderUtils.Numbers.html#parse_int/1-examples"},{"type":"function","title":"WuunderUtils.Numbers.to_decimal/1","doc":"Tries to convert any value to a Decimal.\nIt will also convert a `nil` to a 0.","ref":"WuunderUtils.Numbers.html#to_decimal/1"},{"type":"function","title":"Examples - WuunderUtils.Numbers.to_decimal/1","doc":"iex> WuunderUtils.Numbers.to_decimal(\"15\")\n    Decimal.new(\"15\")\n\n    iex> WuunderUtils.Numbers.to_decimal(\"15\")\n    Decimal.new(\"15\")","ref":"WuunderUtils.Numbers.html#to_decimal/1-examples"},{"type":"module","title":"WuunderUtils.Presence","doc":"Acts as proxy module towards any? functions of String and Map","ref":"WuunderUtils.Presence.html"},{"type":"function","title":"WuunderUtils.Presence.any?/1","doc":"Checks if value is present","ref":"WuunderUtils.Presence.html#any?/1"},{"type":"function","title":"Examples - WuunderUtils.Presence.any?/1","doc":"iex> WuunderUtils.Presence.any?(nil)\n    false\n\n    iex> WuunderUtils.Presence.any?(%{})\n    false\n\n    iex> WuunderUtils.Presence.any?(%{value: 1200})\n    true\n\n    iex> WuunderUtils.Presence.any?(\"\")\n    false\n\n    iex> WuunderUtils.Presence.any?(\"test\")\n    true","ref":"WuunderUtils.Presence.html#any?/1-examples"},{"type":"function","title":"WuunderUtils.Presence.empty?/1","doc":"The inverse of any?","ref":"WuunderUtils.Presence.html#empty?/1"},{"type":"function","title":"Examples - WuunderUtils.Presence.empty?/1","doc":"iex> WuunderUtils.Presence.empty?(nil)\n    true\n\n    iex> WuunderUtils.Presence.empty?(%{})\n    true\n\n    iex> WuunderUtils.Presence.empty?(%{value: 1200})\n    false\n\n    iex> WuunderUtils.Presence.empty?(\"\")\n    true\n\n    iex> WuunderUtils.Presence.empty?(\"test\")\n    false","ref":"WuunderUtils.Presence.html#empty?/1-examples"},{"type":"function","title":"WuunderUtils.Presence.trim/1","doc":"Optionally trims data","ref":"WuunderUtils.Presence.html#trim/1"},{"type":"function","title":"Examples - WuunderUtils.Presence.trim/1","doc":"iex> WuunderUtils.Presence.trim(\" test \")\n    \"test\"\n\n    iex> WuunderUtils.Presence.trim(nil)\n    nil","ref":"WuunderUtils.Presence.html#trim/1-examples"},{"type":"type","title":"WuunderUtils.Presence.t/0","doc":"","ref":"WuunderUtils.Presence.html#t:t/0"},{"type":"module","title":"WuunderUtils.Results","doc":"A set of handy helpers to deal with {:ok, _} or {:error, _} tuples","ref":"WuunderUtils.Results.html"},{"type":"function","title":"WuunderUtils.Results.all_error?/1","doc":"Checks if all results errored","ref":"WuunderUtils.Results.html#all_error?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.all_error?/1","doc":"iex> WuunderUtils.Results.all_error?([\n    ...>   {:error, %Shipment{id: 1}},\n    ...>   {:error, %Shipment{id: 2}}\n    ...> ])\n    true\n\n    iex> WuunderUtils.Results.all_error?([{:ok, %Shipment{id: 2}}, {:error, %Shipment{id: 3}}])\n    false","ref":"WuunderUtils.Results.html#all_error?/1-examples"},{"type":"function","title":"WuunderUtils.Results.all_ok?/1","doc":"Checks if there are no errors and all results are {:ok, ...}","ref":"WuunderUtils.Results.html#all_ok?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.all_ok?/1","doc":"iex> WuunderUtils.Results.all_ok?([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}}\n    ...> ])\n    true\n\n    iex> WuunderUtils.Results.all_ok?([{:ok, %Shipment{id: 2}}, {:error, %Shipment{id: 3}}])\n    false","ref":"WuunderUtils.Results.html#all_ok?/1-examples"},{"type":"function","title":"WuunderUtils.Results.error/1","doc":"Wraps the given value in an error tuple.","ref":"WuunderUtils.Results.html#error/1"},{"type":"function","title":"Examples - WuunderUtils.Results.error/1","doc":"iex> WuunderUtils.Results.error(\"value\")\n    {:error, \"value\"}","ref":"WuunderUtils.Results.html#error/1-examples"},{"type":"function","title":"WuunderUtils.Results.error?/1","doc":"Tests if result contains an error","ref":"WuunderUtils.Results.html#error?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.error?/1","doc":"iex> WuunderUtils.Results.error?({:error, \"error message\"})\n    true\n\n    iex> WuunderUtils.Results.error?(:error)\n    true\n\n    iex> WuunderUtils.Results.error?({:error})\n    false\n\n    iex> WuunderUtils.Results.error?({:ok, \"value\"})\n    false\n\n    iex> WuunderUtils.Results.error?([])\n    false","ref":"WuunderUtils.Results.html#error?/1-examples"},{"type":"function","title":"WuunderUtils.Results.flatten/1","doc":"Flattens a result tuple. Comes in handy when functions return a {:ok, _} or {:error, _} tuple with another set of tuples nested inside of it.","ref":"WuunderUtils.Results.html#flatten/1"},{"type":"function","title":"Examples - WuunderUtils.Results.flatten/1","doc":"iex> WuunderUtils.Results.flatten({:error, {:internal_error, :get_orders, \"Internal Server Error\"}})\n    {:error, :internal_error, :get_orders, \"Internal Server Error\"}\n\n    iex> WuunderUtils.Results.flatten({:error, {:internal_error, :get_orders}, {1, 2}})\n    {:error, :internal_error, :get_orders, 1, 2}\n\n    iex> WuunderUtils.Results.flatten({:error, {:internal_error, :get_orders, [1, 2]}, {1, 2}})\n    {:error, :internal_error, :get_orders, [1, 2], 1, 2}\n\n    iex> WuunderUtils.Results.flatten({:error, :internal_error, :get_orders})\n    {:error, :internal_error, :get_orders}\n\n    iex> WuunderUtils.Results.flatten(:error)\n    :error","ref":"WuunderUtils.Results.html#flatten/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_error/1","doc":"Retrieves the first occurence of an error tuple in the result list","ref":"WuunderUtils.Results.html#get_error/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_error/1","doc":"iex> results = [\n     ...>   {:ok, %Shipment{id: 1}},\n     ...>   {:ok, %Shipment{id: 2}},\n     ...>   {:error, :creation_error}\n     ...> ]\n     ...>\n     ...> WuunderUtils.Results.get_error(results)\n     {:error, :creation_error}\n\n     iex> results = [\n     ...>   {:ok, %Shipment{id: 1}},\n     ...>   {:ok, %Shipment{id: 2}},\n     ...> ]\n     ...>\n     ...> WuunderUtils.Results.get_error(results)\n     nil","ref":"WuunderUtils.Results.html#get_error/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_errors/1","doc":"Retrieves all occurences of an error tuple in the result list","ref":"WuunderUtils.Results.html#get_errors/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_errors/1","doc":"iex> results = [\n     ...>   {:ok, %Shipment{id: 1}},\n     ...>   {:ok, %Shipment{id: 2}},\n     ...>   {:error, \"other-error\"},\n     ...>   {:error, :creation_error}\n     ...> ]\n     ...>\n     ...> WuunderUtils.Results.get_errors(results)\n     [{:error, \"other-error\"}, {:error, :creation_error}]","ref":"WuunderUtils.Results.html#get_errors/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_ok/1","doc":"Retrieve the first :ok result from a list of results. Returns the value\nof OK, not the tuple itself.","ref":"WuunderUtils.Results.html#get_ok/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_ok/1","doc":"iex> results = [\n     ...>   {:ok, %Shipment{id: 1}},\n     ...>   {:ok, %Shipment{id: 2}},\n     ...>   {:error, :creation_error}\n     ...> ]\n     ...>\n     ...> WuunderUtils.Results.get_ok(results)\n     {:ok, %Shipment{id: 1}}\n\n     iex> results = [\n     ...>   {:error, :creation_error}\n     ...> ]\n     ...>\n     ...> WuunderUtils.Results.get_ok(results)\n     nil","ref":"WuunderUtils.Results.html#get_ok/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_oks/1","doc":"Retrieve all :ok results from a list of results. Returns the values of OK,\nnot the tuple itself.","ref":"WuunderUtils.Results.html#get_oks/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_oks/1","doc":"iex> results = [\n     ...>   {:ok, %Shipment{id: 1}},\n     ...>   {:ok, %Shipment{id: 2}},\n     ...>   {:error, :creation_error}\n     ...> ]\n     ...>\n     ...> WuunderUtils.Results.get_oks(results)\n     [{:ok, %WuunderUtils.ResultsTest.Shipment{id: 1, weight: 0}}, {:ok, %WuunderUtils.ResultsTest.Shipment{id: 2, weight: 0}}]","ref":"WuunderUtils.Results.html#get_oks/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_result/1","doc":"Returns error or ok from result list. Gives priority to error in list.","ref":"WuunderUtils.Results.html#get_result/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_result/1","doc":"iex> WuunderUtils.Results.get_result([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}},\n    ...>   {:error, :creation_error},\n    ...>   :error\n    ...> ])\n    {:error, :creation_error}\n\n    iex> WuunderUtils.Results.get_result([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}},\n    ...> ])\n    {:ok, %Shipment{id: 1}}","ref":"WuunderUtils.Results.html#get_result/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_results/1","doc":"Gets a list of errors or a list of ok's.\nGives the priority to list of errors","ref":"WuunderUtils.Results.html#get_results/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_results/1","doc":"iex> WuunderUtils.Results.get_results([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}},\n    ...>   {:error, :creation_error},\n    ...>   :error\n    ...> ])\n    [{:error, :creation_error}, :error]\n\n    iex> WuunderUtils.Results.get_results([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}},\n    ...> ])\n    [{:ok, %Shipment{id: 1}}, {:ok, %Shipment{id: 2}}]","ref":"WuunderUtils.Results.html#get_results/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_value/1","doc":"Retrieves the data is stored inside a {:ok, X} or {:error, Y} tuple.\nOnly gets everything after the :ok or :error. All other values are left alone and just returned.","ref":"WuunderUtils.Results.html#get_value/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_value/1","doc":"iex> WuunderUtils.Results.get_value({:ok, \"value-1\"})\n    \"value-1\"\n\n    iex> WuunderUtils.Results.get_value({:ok, \"value-1\", \"value-2\"})\n    {\"value-1\", \"value-2\"}\n\n    iex> WuunderUtils.Results.get_value({:error, :internal_server_error})\n    :internal_server_error\n\n    iex> WuunderUtils.Results.get_value({:error, :error_a, :error_b, :error_c})\n    {:error_a, :error_b, :error_c}\n\n    iex> WuunderUtils.Results.get_value(:ok)\n    nil\n\n    iex> WuunderUtils.Results.get_value(:error)\n    nil","ref":"WuunderUtils.Results.html#get_value/1-examples"},{"type":"function","title":"WuunderUtils.Results.get_values/1","doc":"Grabs the values of a list of result tuples","ref":"WuunderUtils.Results.html#get_values/1"},{"type":"function","title":"Examples - WuunderUtils.Results.get_values/1","doc":"iex> WuunderUtils.Results.get_values([{:ok, \"value-1\"}])\n    [\"value-1\"]\n\n    iex> WuunderUtils.Results.get_values([{:ok, \"value-1\", \"value-2\"}, {:ok, \"value-3\"}])\n    [{\"value-1\", \"value-2\"}, \"value-3\"]\n\n    iex> WuunderUtils.Results.get_values([{:error, :internal_server_error}])\n    [:internal_server_error]\n\n    iex> WuunderUtils.Results.get_values([:ok, :error])\n    [nil, nil]","ref":"WuunderUtils.Results.html#get_values/1-examples"},{"type":"function","title":"WuunderUtils.Results.has_error?/1","doc":"Checks if any items in the list contains an error","ref":"WuunderUtils.Results.html#has_error?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.has_error?/1","doc":"iex> WuunderUtils.Results.has_error?([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}},\n    ...>   {:error, :creation_error},\n    ...>   :error\n    ...> ])\n    true\n\n    iex> WuunderUtils.Results.has_error?([\n    ...>   {:ok, %Shipment{id: 1}},\n    ...>   {:ok, %Shipment{id: 2}},\n    ...>   :ok\n    ...> ])\n    false","ref":"WuunderUtils.Results.html#has_error?/1-examples"},{"type":"function","title":"WuunderUtils.Results.has_ok?/1","doc":"Checks if there any OK results in the list.","ref":"WuunderUtils.Results.html#has_ok?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.has_ok?/1","doc":"iex> WuunderUtils.Results.has_ok?([{:ok, \"hello world\"}, {:error, :faulty}])\n    true\n\n    iex> WuunderUtils.Results.has_ok?([{:error, \"connection lost\"}, {:error, :faulty}])\n    false","ref":"WuunderUtils.Results.html#has_ok?/1-examples"},{"type":"macro","title":"WuunderUtils.Results.is_error_result/1","doc":"","ref":"WuunderUtils.Results.html#is_error_result/1"},{"type":"macro","title":"WuunderUtils.Results.is_error_tuple/1","doc":"","ref":"WuunderUtils.Results.html#is_error_tuple/1"},{"type":"macro","title":"WuunderUtils.Results.is_ok_result/1","doc":"","ref":"WuunderUtils.Results.html#is_ok_result/1"},{"type":"macro","title":"WuunderUtils.Results.is_ok_tuple/1","doc":"","ref":"WuunderUtils.Results.html#is_ok_tuple/1"},{"type":"macro","title":"WuunderUtils.Results.is_result/1","doc":"","ref":"WuunderUtils.Results.html#is_result/1"},{"type":"macro","title":"WuunderUtils.Results.is_result_tuple/1","doc":"","ref":"WuunderUtils.Results.html#is_result_tuple/1"},{"type":"function","title":"WuunderUtils.Results.ok/1","doc":"Wraps the given value in an ok tuple.","ref":"WuunderUtils.Results.html#ok/1"},{"type":"function","title":"Examples - WuunderUtils.Results.ok/1","doc":"iex> WuunderUtils.Results.ok(\"value\")\n    {:ok, \"value\"}","ref":"WuunderUtils.Results.html#ok/1-examples"},{"type":"function","title":"WuunderUtils.Results.ok?/1","doc":"Tests if result is OK","ref":"WuunderUtils.Results.html#ok?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.ok?/1","doc":"iex> WuunderUtils.Results.ok?({:ok, \"value\"})\n    true\n\n    iex> WuunderUtils.Results.ok?(:ok)\n    true\n\n    iex> WuunderUtils.Results.ok?(\"some-value\")\n    false\n\n    iex> WuunderUtils.Results.ok?({:error, \"error message\"})\n    false\n\n    iex> WuunderUtils.Results.ok?([])\n    false","ref":"WuunderUtils.Results.html#ok?/1-examples"},{"type":"function","title":"WuunderUtils.Results.result?/1","doc":"Checks if given value is :ok, :error or {:ok, _} or {:error, _}","ref":"WuunderUtils.Results.html#result?/1"},{"type":"function","title":"Examples - WuunderUtils.Results.result?/1","doc":"iex> WuunderUtils.Results.result?({:ok, \"value\"})\n    true\n\n    iex> WuunderUtils.Results.result?({:error, \"value\"})\n    true\n\n    iex> WuunderUtils.Results.result?(:ok)\n    true\n\n    iex> WuunderUtils.Results.result?(:error)\n    true\n\n    iex> WuunderUtils.Results.result?({:error})\n    false\n\n    iex> WuunderUtils.Results.result?({:ok})\n    false\n\n    iex> WuunderUtils.Results.result?(\"value\")\n    false","ref":"WuunderUtils.Results.html#result?/1-examples"},{"type":"type","title":"WuunderUtils.Results.error/0","doc":"","ref":"WuunderUtils.Results.html#t:error/0"},{"type":"type","title":"WuunderUtils.Results.error_tuple/0","doc":"","ref":"WuunderUtils.Results.html#t:error_tuple/0"},{"type":"type","title":"WuunderUtils.Results.ok/0","doc":"","ref":"WuunderUtils.Results.html#t:ok/0"},{"type":"type","title":"WuunderUtils.Results.ok_tuple/0","doc":"","ref":"WuunderUtils.Results.html#t:ok_tuple/0"},{"type":"type","title":"WuunderUtils.Results.result/0","doc":"","ref":"WuunderUtils.Results.html#t:result/0"},{"type":"type","title":"WuunderUtils.Results.result_list/0","doc":"","ref":"WuunderUtils.Results.html#t:result_list/0"},{"type":"module","title":"WuunderUtils.Strings","doc":"Contains a set of String helpers","ref":"WuunderUtils.Strings.html"},{"type":"function","title":"WuunderUtils.Strings.any?/1","doc":"The inverse of `is_nil_or_empty`","ref":"WuunderUtils.Strings.html#any?/1"},{"type":"function","title":"Examples - WuunderUtils.Strings.any?/1","doc":"iex> WuunderUtils.Strings.any?(\"   \")\n    false\n\n    iex> WuunderUtils.Strings.any?(nil)\n    false\n\n    iex> WuunderUtils.Strings.any?(\"yes\")\n    true","ref":"WuunderUtils.Strings.html#any?/1-examples"},{"type":"function","title":"WuunderUtils.Strings.capitalize/1","doc":"Capitalizes each word in a given string.\nNote that it will downcase the remainders of each word by default.","ref":"WuunderUtils.Strings.html#capitalize/1"},{"type":"function","title":"Examples - WuunderUtils.Strings.capitalize/1","doc":"iex> WuunderUtils.Strings.capitalize(\"this is sparta!\")\n    \"This Is Sparta!\"\n\n    iex> WuunderUtils.Strings.capitalize(\"is this spArTA?\")\n    \"Is This Sparta?\"\n\n    iex> WuunderUtils.Strings.capitalize(\"Michał\")\n    \"Michał\"\n\n    iex> WuunderUtils.Strings.capitalize(\"łukasz\")\n    \"Łukasz\"","ref":"WuunderUtils.Strings.html#capitalize/1-examples"},{"type":"function","title":"WuunderUtils.Strings.clean/1","doc":"Trims and cleans up double spaces. Converts `nil` to empty string.","ref":"WuunderUtils.Strings.html#clean/1"},{"type":"function","title":"Examples - WuunderUtils.Strings.clean/1","doc":"iex> WuunderUtils.Strings.clean(\" well    this is a sentence\")\n    \"well this is a sentence\"","ref":"WuunderUtils.Strings.html#clean/1-examples"},{"type":"function","title":"WuunderUtils.Strings.compare/2","doc":"Compares two strings, ignoring the casing:","ref":"WuunderUtils.Strings.html#compare/2"},{"type":"function","title":"Examples - WuunderUtils.Strings.compare/2","doc":"iex> WuunderUtils.Strings.compare(\"case_x\", \"CASE_X\")\n  true\n\n  iex> WuunderUtils.Strings.compare(\"CASE_X\", \"CASE_X\")\n  true\n\n  iex> WuunderUtils.Strings.compare(\"CASE_X\", \"CaSe_X\")\n  true\n\n  iex> WuunderUtils.Strings.compare(\"CASE_Y\", \"CASE_X\")\n  false\n\n  iex> WuunderUtils.Strings.compare(\"CASE_y\", \"CASE_x\")\n  false","ref":"WuunderUtils.Strings.html#compare/2-examples"},{"type":"function","title":"WuunderUtils.Strings.empty?/1","doc":"Checks if given value is nil, or a string that (after trimming) is empty","ref":"WuunderUtils.Strings.html#empty?/1"},{"type":"function","title":"Examples - WuunderUtils.Strings.empty?/1","doc":"iex> WuunderUtils.Strings.empty?(nil)\n    true\n\n    iex> WuunderUtils.Strings.empty?(\"   \")\n    true\n\n    iex> WuunderUtils.Strings.empty?(\"a string\")\n    false","ref":"WuunderUtils.Strings.html#empty?/1-examples"},{"type":"function","title":"WuunderUtils.Strings.empty_to_nil/1","doc":"Converts an empty string to nil or returns the original string","ref":"WuunderUtils.Strings.html#empty_to_nil/1"},{"type":"function","title":"Examples - WuunderUtils.Strings.empty_to_nil/1","doc":"iex> WuunderUtils.Strings.empty_to_nil(nil)\n    nil\n\n    iex> WuunderUtils.Strings.empty_to_nil(\"\")\n    nil\n\n    iex> WuunderUtils.Strings.empty_to_nil(\"    \")\n    nil\n\n    iex> WuunderUtils.Strings.empty_to_nil(\"this_is_a_string\")\n    \"this_is_a_string\"","ref":"WuunderUtils.Strings.html#empty_to_nil/1-examples"},{"type":"function","title":"WuunderUtils.Strings.inspect_value/1","doc":"Converts any given value to a string by using `inspect`.\nIf the given value is already a string, the value is left as it is.\nEvery value is truncated to max 255 chars.","ref":"WuunderUtils.Strings.html#inspect_value/1"},{"type":"function","title":"Examples - WuunderUtils.Strings.inspect_value/1","doc":"iex> WuunderUtils.Strings.inspect_value(\"this is a string\")\n    \"this is a string\"\n\n    iex> \"This is \" <> WuunderUtils.Strings.inspect_value(\"a string\")\n    \"This is a string\"\n\n    iex> WuunderUtils.Strings.inspect_value(%{a: 10})\n    \"%{a: 10}\"","ref":"WuunderUtils.Strings.html#inspect_value/1-examples"},{"type":"macro","title":"WuunderUtils.Strings.is_empty/1","doc":"","ref":"WuunderUtils.Strings.html#is_empty/1"},{"type":"function","title":"WuunderUtils.Strings.truncate/3","doc":"Truncates a string with a given string. If string is longer than\ngiven length, it will add a suffix to that string.\nBy default this is `...`","ref":"WuunderUtils.Strings.html#truncate/3"},{"type":"function","title":"Examples - WuunderUtils.Strings.truncate/3","doc":"iex> WuunderUtils.Strings.truncate(\"this is a long string\", 30)\n    \"this is a long string\"\n\n    iex> WuunderUtils.Strings.truncate(\"this is a long string\", 21)\n    \"this is a long string\"\n\n    iex> WuunderUtils.Strings.truncate(\"this is a long string\", 20)\n    \"this is a long st...\"\n\n    iex> WuunderUtils.Strings.truncate(\"this is a long string\", 10)\n    \"this is...\"\n\n    iex> WuunderUtils.Strings.truncate(\"this is a long string\", 20, \"... data truncated\")\n    \"th... data truncated\"\n\n    iex> WuunderUtils.Strings.truncate(\"this is a long string\", 21, \"... data truncated\")\n    \"this is a long string\"\n\n    iex> WuunderUtils.Strings.truncate(\"this is a long string\", 10, \"very long suffix\")\n    \"very long \"","ref":"WuunderUtils.Strings.html#truncate/3-examples"},{"type":"extras","title":"WuunderUtils","doc":"# WuunderUtils\n\nContains a set of modules that makes Elixir development more fun and productive.\n\n![Build status](https://github.com/wuunder/wuunder_utils/actions/workflows/ci.yml/badge.svg)\n[![Coverage Status](https://coveralls.io/repos/github/wuunder/wuunder_utils/badge.svg?branch=main)](https://coveralls.io/github/wuunder/wuunder_utils?branch=main)\n[![Hex.pm](https://img.shields.io/hexpm/v/wuunder_utils.svg)](https://hex.pm/packages/wuunder_utils)","ref":"readme.html"},{"type":"extras","title":"Installation - WuunderUtils","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `wuunder_utils` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:wuunder_utils, \"~> 0.10.2\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.9 (2024-10-24) - Changelog","doc":"","ref":"changelog.html#v0-9-2024-10-24"},{"type":"extras","title":"Backwards incompatible changes - Changelog","doc":"* Renamed `WuunderUtils.Maps.delete_field` to `WuunderUtils.Maps.delete`\n  * Renamed `WuunderUtils.Maps.delete_field_in` to `WuunderUtils.Maps.deep_delete`\n  * Renamed `WuunderUtils.Maps.get_field` to `WuunderUtils.Maps.get`\n  * Renamed `WuunderUtils.Maps.get_field_in` to `WuunderUtils.Maps.deep_get`\n  * Renamed `WuunderUtils.Maps.get_fields_in` to `WuunderUtils.Maps.deep_get_values`\n  * Renamed `WuunderUtils.Maps.put_field` to `WuunderUtils.Maps.put`\n  * Renamed `WuunderUtils.Maps.put_field_in` to `WuunderUtils.Maps.deep_put`\n  * Renamed `WuunderUtils.Maps.has_only_atom_keys?` to `WuunderUtils.Maps.only_atom_keys?`\n  * Renamed `WuunderUtils.Maps.alias_fields` to `WuunderUtils.Maps.rename_keys`\n  * Renamed `WuunderUtils.Maps.map_all` to `WuunderUtils.Maps.map`","ref":"changelog.html#backwards-incompatible-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added `stringify_keys` helper in `WuunderUtils.Maps`\n  * Added `atomize_keys` helper in `WuunderUtils.Maps`","ref":"changelog.html#enhancements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}